/*
 TECNISA - TECNOLOGIA EM INFORMTICA

 NOME: RECALCULO_ITEM

 DESCRIO:
 PROCEDIMENTO PARA ATUALIZAO DO VALOR CONTABIL DO ITEM, DEVIDO A ALTERAO REALIZADA NA TELA DE
 MANUTENO DE DOCUMENTOS.

 CRIAO:
 09/06/04 - REJANE PRISCILA LEITE

 @C:\WIN_V4\SQL\END_CONV\ORACLE\5020_FISSTPO.SQL

 RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
 */

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'RECALCULO_ITEM' AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID              AND
	        U.NAME = USER)

DROP PROCEDURE RECALCULO_ITEM
GO

CREATE PROCEDURE RECALCULO_ITEM  @P_FILIAL       VARCHAR(04),
                                 @P_LANCTONF     VARCHAR(10),
                                 @P_IDORIGDESTNF VARCHAR(01),
                                 @P_IDENTRSAIDOP VARCHAR(01),
                                 @P_CDTIPOOPER   VARCHAR(02),
                                 @P_IDOPERDEVONF VARCHAR(01)

AS
   DECLARE @V_TOTAPRODENCA                 NUMERIC;
   DECLARE @V_VRBRUTO                      NUMERIC;
   DECLARE @V_VRCONTAB                     NUMERIC;
   DECLARE @V_TOTAPRENIMPO                 NUMERIC;
   DECLARE @V_PRODUENCARGO                 NUMERIC;
   DECLARE @V_TAXABASECALC                 NUMERIC;
   DECLARE @V_TAXAALIQUOTA                 NUMERIC;
   DECLARE @V_TOTAIMPBCALC                 NUMERIC;
   DECLARE @V_VRIMPOSTO                    NUMERIC;
   DECLARE @V_IMPOCONTAB                   NUMERIC;
   DECLARE @V_IMPOSINFO                    NUMERIC;
   DECLARE @V_CDIMPOSTRIB                  VARCHAR(02);
   DECLARE @V_IDACRPRODENTRNF             VARCHAR(01);

   /*VARIAVEIS DO CURSOR C_ITEMPRODUTO*/
   DECLARE @C_ITEMPRODUTO_VRTOTAITEM       NUMERIC(16,2);
   DECLARE @C_ITEMPRODUTO_VRDESCITEM       NUMERIC(16,2);
   DECLARE @C_ITEMPRODUTO_CDPRODUTO        VARCHAR(10);
   DECLARE @C_ITEMPRODUTO_NRSEQITPROD      VARCHAR(03);
   DECLARE @C_ITEMPRODUTO_CDCSTINFUSU      VARCHAR(03);
   DECLARE @C_ITEMPRODUTO_CDCFOPINFUSU     VARCHAR(10);
   DECLARE @C_ITEMPRODUTO_CDSUFXINFUSU     VARCHAR(03);
   DECLARE @C_ITEMPRODUTO_CDARVPROD        VARCHAR(20);

   /*VARIAVEIS DO CURSOR C_ITEMENCARGO*/
   DECLARE @C_ITEMENCARGO_CDENCARGO        VARCHAR(02);
   DECLARE @C_ITEMENCARGO_VRITEMENCA       NUMERIC(16,2);
   DECLARE @C_ITEMENCARGO_IDENCARGO        VARCHAR(01);
   DECLARE @C_ITEMENCARGO_CDCTBLENTREN     VARCHAR(20);
   DECLARE @C_ITEMENCARGO_CDCTBLSAIDEN     VARCHAR(20);

   /*VARIAVEIS DO CURSOR C_VRLIQRATEIO*/
   DECLARE @C_VRLIQRATEIO_NRSEQITPROD      VARCHAR(04);
   DECLARE @C_VRLIQRATEIO_VRLIQUIDO        NUMERIC(16,2);

   /*VARIAVEIS DO CURSOR C_ATUAVRCONT */
   DECLARE @C_ATUAVRCONT_NRSEQITPROD       VARCHAR(04);
   DECLARE @C_ATUAVRCONT_VRLIQUIDO         NUMERIC(16,2);

   /*VARIAVEIS DO CURSOR C_PRODUTO*/
   DECLARE @C_PRODUTO_NRSEQITPROD          VARCHAR(04);
   DECLARE @C_PRODUTO_CDIMPOSTO            VARCHAR(02);
   DECLARE @C_PRODUTO_VRPERREDBCIT         NUMERIC(10,2);
   DECLARE @C_PRODUTO_VRALIQITEM           NUMERIC(10,2);
   DECLARE @C_PRODUTO_VRPARDEDIT           NUMERIC(10,2);
   DECLARE @C_PRODUTO_CDFISCALIT           VARCHAR(01);
   DECLARE @C_PRODUTO_VRIMPOSTOIT          NUMERIC(16,2);
   DECLARE @C_PRODUTO_IDTRATIMPO           VARCHAR(01);
   DECLARE @C_PRODUTO_IDIMPORECUP          VARCHAR(01);
   DECLARE @C_PRODUTO_CDCCTBLPASS          VARCHAR(20);
   DECLARE @C_PRODUTO_CDCCTBLATIV          VARCHAR(20);
   DECLARE @C_PRODUTO_NRITPROIMPOS         VARCHAR(01);
   DECLARE @C_PRODUTO_IDVALORINFO          VARCHAR(01);
   DECLARE @C_PRODUTO_IDTRIMPSTII          VARCHAR(01);

   DECLARE @V_IDIMPOBCALTPOP               VARCHAR(01);
BEGIN

   DECLARE C_ITEMPRODUTO CURSOR FOR (SELECT VRTOTAITEM, VRDESCITEM, IT.CDPRODUTO, NRSEQITPROD,
                                            CDCSTINFUSU, CDCFOPINFUSU, CDSUFXINFUSU, P.CDARVPROD
                                     FROM ITEMPRODUTO IT, PRODUTO P
                                     WHERE IT.CDFILIAL     = @P_FILIAL        AND
                                           IT.NRLANCTONF   = @P_LANCTONF      AND
                                           IT.CDPRODUTO    = P.CDPRODUTO);

   OPEN C_ITEMPRODUTO;

   FETCH NEXT FROM C_ITEMPRODUTO INTO @C_ITEMPRODUTO_VRTOTAITEM, @C_ITEMPRODUTO_VRDESCITEM, @C_ITEMPRODUTO_CDPRODUTO,
                                      @C_ITEMPRODUTO_NRSEQITPROD, @C_ITEMPRODUTO_CDCSTINFUSU, @C_ITEMPRODUTO_CDCFOPINFUSU,
                                      @C_ITEMPRODUTO_CDSUFXINFUSU, @C_ITEMPRODUTO_CDARVPROD;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      UPDATE ITEMPRODUTO
      SET VRCONTITEM = (VRTOTAITEM - VRDESCITEM)
      WHERE (CDFILIAL    = @P_FILIAL)   AND
            (NRLANCTONF  = @P_LANCTONF) AND
            (NRSEQITPROD = @C_ITEMPRODUTO_NRSEQITPROD);

      FETCH NEXT FROM C_ITEMPRODUTO INTO @C_ITEMPRODUTO_VRTOTAITEM, @C_ITEMPRODUTO_VRDESCITEM, @C_ITEMPRODUTO_CDPRODUTO,
                                         @C_ITEMPRODUTO_NRSEQITPROD, @C_ITEMPRODUTO_CDCSTINFUSU, @C_ITEMPRODUTO_CDCFOPINFUSU,
                                         @C_ITEMPRODUTO_CDSUFXINFUSU, @C_ITEMPRODUTO_CDARVPROD;

   END;

   CLOSE C_ITEMPRODUTO;
   DEALLOCATE C_ITEMPRODUTO;

   --RATEIO DOS ENCARGOS.


   DECLARE C_ITEMENCARGO CURSOR FOR (SELECT IE.CDENCARGO AS CDENCARGO, VRITEMENCA, IDENCARGO,
                                            EN.CDCTBLENTREN, EN.CDCTBLSAIDEN
                                     FROM ITEMENCARGO IE, ENCARGO EN
                                     WHERE (IE.CDFILIAL   = @P_FILIAL)     AND
                                           (IE.NRLANCTONF = @P_LANCTONF)   AND
                                           (IE.VRITEMENCA > 0)             AND
                                           (EN.CDENCARGO  = IE.CDENCARGO));
   OPEN C_ITEMENCARGO;

   FETCH NEXT FROM C_ITEMENCARGO INTO @C_ITEMENCARGO_CDENCARGO, @C_ITEMENCARGO_VRITEMENCA, @C_ITEMENCARGO_IDENCARGO,
                                      @C_ITEMENCARGO_CDCTBLENTREN, @C_ITEMENCARGO_CDCTBLSAIDEN;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_TOTAPRODENCA = 0;

      DECLARE C_VRLIQRATEIO CURSOR FOR (SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
                                        FROM ITEMPRODUTO IP, ITEMPROIMPOS II
                                        WHERE (IP.CDFILIAL    = @P_FILIAL)       AND
                                              (IP.NRLANCTONF  = @P_LANCTONF)     AND
                                              (II.CDFILIAL    = IP.CDFILIAL)     AND
                                              (II.NRLANCTONF  = IP.NRLANCTONF)   AND
                                              (II.NRSEQITPROD = IP.NRSEQITPROD)  AND
                                              (EXISTS(SELECT BC.CDIMPOSTO
                                                      FROM BASECALC BC
                                                      WHERE (BC.CDENCARGO = @C_ITEMENCARGO_CDENCARGO) AND
                                                            (BC.CDIMPOSTO = II.CDIMPOSTO)             AND
                                                            (BC.CDIMPOSTO = (SELECT MIN(B.CDIMPOSTO)
                                                                             FROM BASECALC B
                                                                             WHERE B.CDENCARGO = @C_ITEMENCARGO_CDENCARGO)))));
      OPEN C_VRLIQRATEIO;

      FETCH NEXT FROM C_VRLIQRATEIO INTO @C_VRLIQRATEIO_NRSEQITPROD, @C_VRLIQRATEIO_VRLIQUIDO;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         IF NOT (@C_VRLIQRATEIO_VRLIQUIDO IS NULL) BEGIN
            SET @V_TOTAPRODENCA = @V_TOTAPRODENCA + @C_VRLIQRATEIO_VRLIQUIDO;
         END;

         FETCH NEXT FROM C_VRLIQRATEIO INTO @C_VRLIQRATEIO_NRSEQITPROD, @C_VRLIQRATEIO_VRLIQUIDO;
      END;

      CLOSE C_VRLIQRATEIO;
      DEALLOCATE C_VRLIQRATEIO;


      IF @V_TOTAPRODENCA = 0 BEGIN
         SELECT @V_TOTAPRODENCA = SUM(VRTOTAITEM - VRDESCITEM)
         FROM ITEMPRODUTO IP
         WHERE (IP.CDFILIAL   = @P_FILIAL)   AND
               (IP.NRLANCTONF = @P_LANCTONF);

         IF NOT @V_TOTAPRODENCA IS NULL BEGIN

            DECLARE C_ATUAVRCONT CURSOR FOR (SELECT IP.NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
                                             FROM ITEMPRODUTO IP
                                             WHERE (IP.CDFILIAL    = @P_FILIAL) AND
                                                   (IP.NRLANCTONF  = @P_LANCTONF));
            OPEN C_ATUAVRCONT;
            FETCH NEXT FROM C_ATUAVRCONT INTO @C_ATUAVRCONT_NRSEQITPROD, @C_ATUAVRCONT_VRLIQUIDO;

            WHILE (@@FETCH_STATUS = 0) BEGIN
               IF (@C_ITEMENCARGO_IDENCARGO = 'A') BEGIN
                  SET @V_VRBRUTO  = (@C_ITEMENCARGO_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE BEGIN
                  IF (@C_ITEMENCARGO_IDENCARGO = 'D') BEGIN
                     SET @V_VRBRUTO  = - (@C_ITEMENCARGO_VRITEMENCA/@V_TOTAPRODENCA);
                  END
                  ELSE BEGIN
                     SET @V_VRBRUTO = 0;
                  END;
               END;

               IF ((@C_ITEMENCARGO_CDCTBLSAIDEN IS NULL) AND (@P_IDENTRSAIDOP = 'S')) OR
                  ((@C_ITEMENCARGO_CDCTBLENTREN IS NULL) AND (@P_IDENTRSAIDOP = 'E')) BEGIN
                  SET @V_VRCONTAB = @V_VRBRUTO;
               END
               ELSE BEGIN
                  SET @V_VRCONTAB = 0;
               END;

               UPDATE ITEMPRODUTO
               SET VRCONTITEM = VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM))
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @C_ATUAVRCONT_NRSEQITPROD;


               FETCH NEXT FROM C_ATUAVRCONT INTO @C_ATUAVRCONT_NRSEQITPROD, @C_ATUAVRCONT_VRLIQUIDO;
            END;

            CLOSE C_ATUAVRCONT;
            DEALLOCATE C_ATUAVRCONT;

         END;
      END
      ELSE BEGIN
         DECLARE C_ATUAVRCONT CURSOR FOR (SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
                                          FROM ITEMPRODUTO IP, ITEMPROIMPOS II
                                          WHERE (IP.CDFILIAL    = @P_FILIAL)       AND
                                                (IP.NRLANCTONF  = @P_LANCTONF)     AND
                                                (II.CDFILIAL    = IP.CDFILIAL)     AND
                                                (II.NRLANCTONF  = IP.NRLANCTONF)   AND
                                                (II.NRSEQITPROD = IP.NRSEQITPROD)  AND
                                                (EXISTS(SELECT BC.CDIMPOSTO
                                                        FROM BASECALC BC
                                                        WHERE (BC.CDENCARGO = @C_ITEMENCARGO_CDENCARGO) AND
                                                              (BC.CDIMPOSTO = II.CDIMPOSTO)             AND
                                                              (BC.CDIMPOSTO = (SELECT MIN(B.CDIMPOSTO)
                                                                               FROM BASECALC B
                                                                               WHERE B.CDENCARGO = @C_ITEMENCARGO_CDENCARGO)))));
         OPEN C_ATUAVRCONT;
         FETCH NEXT FROM C_ATUAVRCONT INTO @C_ATUAVRCONT_NRSEQITPROD, @C_ATUAVRCONT_VRLIQUIDO;
         WHILE (@@FETCH_STATUS = 0) BEGIN

            IF (@C_ITEMENCARGO_IDENCARGO = 'A') BEGIN
               SET @V_VRBRUTO  = (@C_ITEMENCARGO_VRITEMENCA/@V_TOTAPRODENCA);
            END
            ELSE BEGIN
               IF (@C_ITEMENCARGO_IDENCARGO = 'D') BEGIN
                  SET @V_VRBRUTO  = - (@C_ITEMENCARGO_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE BEGIN
                  SET @V_VRBRUTO = 0;
               END;
            END;

            IF ((@C_ITEMENCARGO_CDCTBLSAIDEN IS NULL) AND (@P_IDENTRSAIDOP = 'S')) OR
               ((@C_ITEMENCARGO_CDCTBLENTREN IS NULL) AND (@P_IDENTRSAIDOP = 'E')) BEGIN
               SET @V_VRCONTAB = @V_VRBRUTO;
            END
            ELSE BEGIN
               SET @V_VRCONTAB = 0;
            END;

            UPDATE ITEMPRODUTO
            SET VRCONTITEM = VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM))
            WHERE CDFILIAL    = @P_FILIAL   AND
                  NRLANCTONF  = @P_LANCTONF AND
                  NRSEQITPROD = @C_ATUAVRCONT_NRSEQITPROD;


            FETCH NEXT FROM C_ATUAVRCONT INTO @C_ATUAVRCONT_NRSEQITPROD, @C_ATUAVRCONT_VRLIQUIDO;
         END;
         CLOSE C_ATUAVRCONT;
         DEALLOCATE C_ATUAVRCONT;

      END;

      FETCH NEXT FROM C_ITEMENCARGO INTO @C_ITEMENCARGO_CDENCARGO, @C_ITEMENCARGO_VRITEMENCA, @C_ITEMENCARGO_IDENCARGO,
                                         @C_ITEMENCARGO_CDCTBLENTREN, @C_ITEMENCARGO_CDCTBLSAIDEN;

   END;
-- FIM DO RATEIO DOS ENCARGOS
   CLOSE C_ITEMENCARGO;
   DEALLOCATE C_ITEMENCARGO;


   DECLARE C_PRODUTO CURSOR FOR (SELECT IP.NRSEQITPROD AS NRSEQITPROD, II.CDIMPOSTO,
                                        II.VRPERREDBCIT, II.VRALIQITEM, II.VRPARDEDIT, II.CDFISCALIT, II.VRIMPOSTOIT,
                                        IM.IDTRATIMPO, IM.IDIMPORECUP, IM.CDCCTBLPASS, IM.CDCCTBLATIV,
                                        II.NRITPROIMPOS, ISNULL(II.IDVALORINFIT, 'N') AS IDVALORINFO, IDTRIMPSTII
                                 FROM ITEMPRODUTO IP, ITEMPROIMPOS II, IMPOSTO IM
                                 WHERE (IP.CDFILIAL     = @P_FILIAL)           AND
                                       (IP.NRLANCTONF   = @P_LANCTONF)         AND
                                       (II.CDFILIAL     = @P_FILIAL)           AND
                                       (II.NRLANCTONF   = @P_LANCTONF)         AND
                                       (II.NRSEQITPROD  = IP.NRSEQITPROD)      AND
                                       (II.CDIMPOSTO    = IM.CDIMPOSTO)        AND
                                       (II.NRITPROIMPOS = '1'));
   OPEN C_PRODUTO;
   FETCH NEXT FROM C_PRODUTO INTO @C_PRODUTO_NRSEQITPROD, @C_PRODUTO_CDIMPOSTO, @C_PRODUTO_VRPERREDBCIT,
                                  @C_PRODUTO_VRALIQITEM,  @C_PRODUTO_VRPARDEDIT, @C_PRODUTO_CDFISCALIT,
                                  @C_PRODUTO_VRIMPOSTOIT, @C_PRODUTO_IDTRATIMPO, @C_PRODUTO_IDIMPORECUP,
                                  @C_PRODUTO_CDCCTBLPASS, @C_PRODUTO_CDCCTBLATIV, @C_PRODUTO_NRITPROIMPOS,
                                  @C_PRODUTO_IDVALORINFO, @C_PRODUTO_IDTRIMPSTII;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_IDIMPOBCALTPOP = NULL;

      SELECT @V_IDIMPOBCALTPOP = MAX('S'), @V_TOTAIMPBCALC = SUM(II.VRIMPOSTOIT)
        FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALCTPOPER BC
      WHERE BC.IDENTRSAIDOP = @P_IDENTRSAIDOP
        AND BC.CDTIPOOPER = @P_CDTIPOOPER
        AND BC.CDIMPOSTO = @C_PRODUTO_CDIMPOSTO
        AND IP.CDFILIAL = @P_FILIAL
        AND IP.NRLANCTONF = @P_LANCTONF
        AND IP.NRSEQITPROD = @C_PRODUTO_NRSEQITPROD
        AND II.CDFILIAL = @P_FILIAL
        AND II.NRLANCTONF = @P_LANCTONF
        AND II.NRSEQITPROD  = IP.NRSEQITPROD
        AND II.CDIMPOSTO    = BC.CDIMPOBCALC
        AND II.NRITPROIMPOS = '1'
        AND ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL))
        AND ((SUBSTRING(IP.CDFISOPEITEM,2,10) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL))
        AND ((@C_PRODUTO_CDFISCALIT = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL));

      IF @V_IDIMPOBCALTPOP IS NULL BEGIN

         SELECT @V_TOTAIMPBCALC = SUM(I.VRIMPOSTOIT)
         FROM ITEMPRODUTO IP, ITEMPROIMPOS I, BASECALC BC
         WHERE (BC.CDIMPOSTO    = @C_PRODUTO_CDIMPOSTO)    AND
               (IP.CDFILIAL     = @P_FILIAL)               AND
               (IP.NRLANCTONF   = @P_LANCTONF)             AND
               (IP.NRSEQITPROD  = @C_PRODUTO_NRSEQITPROD)  AND
               (I.CDFILIAL      = @P_FILIAL)               AND
               (I.NRLANCTONF    = @P_LANCTONF)             AND
               (I.NRSEQITPROD   = IP.NRSEQITPROD)          AND
               (I.CDIMPOSTO     = BC.CDIMPOBCALC)          AND
               (I.NRITPROIMPOS  = '1')                     AND
               ((SUBSTRING(IP.CDSITUTRIBPR,2,2)  = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL)) AND
               ((SUBSTRING(IP.CDFISOPEITEM,2,10) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL)) AND
               ((@C_PRODUTO_CDFISCALIT           = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)) AND
               (BC.IDTIPOBCALC   = 'I');
      END;

      SET @V_IMPOSINFO = @C_PRODUTO_VRIMPOSTOIT;
      SET @V_IMPOCONTAB = 0;

      IF (@P_IDENTRSAIDOP = 'E') BEGIN
         IF (@C_PRODUTO_IDIMPORECUP = 'S') BEGIN
            IF (@C_PRODUTO_CDFISCALIT = '1') BEGIN
               IF (@C_PRODUTO_CDCCTBLATIV IS NOT NULL) BEGIN
                  IF @C_PRODUTO_IDTRATIMPO = 'V' BEGIN
                     SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                  END;
               END;
            END
            ELSE BEGIN
               IF @C_PRODUTO_IDTRATIMPO = 'A' BEGIN
                  SET @V_IMPOCONTAB = @V_IMPOSINFO;
               END
               ELSE BEGIN
                 IF @C_PRODUTO_IDTRATIMPO IN ('D','R') BEGIN
                    SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                 END;
               END;
            END;
         END
         ELSE BEGIN
            IF NOT(@C_PRODUTO_CDCCTBLPASS IS NULL) BEGIN
               IF @C_PRODUTO_IDTRATIMPO = 'V' BEGIN
                  SET @V_IMPOCONTAB = - @V_IMPOSINFO;
               END
               ELSE BEGIN
                  IF @C_PRODUTO_IDTRATIMPO = 'A' BEGIN

                     SELECT @V_IDACRPRODENTRNF = ISNULL(MAX(IDACRPRODENTRNF), 'N')
                       FROM IMPOSTO
                      WHERE CDIMPOSTO = @C_PRODUTO_CDIMPOSTO;

                     IF @V_IDACRPRODENTRNF = 'S' BEGIN
                        SET @V_IMPOCONTAB = @V_IMPOSINFO;
                     END;
                  END;
               END;
            END
            ELSE BEGIN
               IF @C_PRODUTO_IDTRATIMPO = 'A' BEGIN
                  SET @V_IMPOCONTAB = @V_IMPOSINFO;
               END
               ELSE BEGIN
                  IF @C_PRODUTO_IDTRATIMPO IN ('D','R') BEGIN
                     SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                  END;
               END;
            END;
         END;
      END
      ELSE BEGIN
         IF (@C_PRODUTO_IDTRATIMPO = 'A') BEGIN
            IF ((@V_CDIMPOSTRIB IS NOT NULL) AND (@C_PRODUTO_IDTRIMPSTII = '0')) OR
                (@V_CDIMPOSTRIB IS NULL) BEGIN
               SET @V_IMPOCONTAB = @V_IMPOSINFO;
            END;
         END
         ELSE BEGIN
            IF (@C_PRODUTO_IDTRATIMPO = 'D') BEGIN
               IF ((@C_PRODUTO_IDIMPORECUP = 'S') AND (@C_PRODUTO_CDFISCALIT <> '1')) OR
                  ((@C_PRODUTO_IDIMPORECUP <> 'S') AND (@C_PRODUTO_CDCCTBLATIV IS NULL)) BEGIN
                  SET @V_IMPOCONTAB = - @V_IMPOSINFO;
               END;
            END
            ELSE BEGIN
               IF (@C_PRODUTO_IDTRATIMPO = 'R') BEGIN
                  IF (@C_PRODUTO_IDIMPORECUP = 'S') BEGIN
                     IF (@C_PRODUTO_CDCCTBLATIV IS NULL) OR
                        (@C_PRODUTO_CDFISCALIT <> '1') BEGIN
                        SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                     END;
                  END
                  ELSE BEGIN
                     IF (@C_PRODUTO_CDCCTBLATIV IS NULL) BEGIN
                        SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                     END;
                  END;
               END
               ELSE BEGIN
                  IF @C_PRODUTO_IDTRATIMPO = 'V' BEGIN
                     IF (@C_PRODUTO_IDIMPORECUP = 'S') AND (@P_IDORIGDESTNF = 'L') BEGIN
                        IF (@C_PRODUTO_CDCCTBLPASS IS NOT NULL) AND
                           (@C_PRODUTO_CDFISCALIT = '1') BEGIN
                           SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                        END;
                     END;
                  END;
               END;
            END;
         END;
      END;

      IF (@P_IDOPERDEVONF = 'S') OR ((@P_IDENTRSAIDOP = 'E') AND (@P_CDTIPOOPER = '16')) BEGIN
         IF (@C_PRODUTO_IDTRATIMPO = 'A') BEGIN
           IF NOT (((@C_PRODUTO_IDIMPORECUP = 'S')  AND (@C_PRODUTO_CDFISCALIT = '1')) OR
                   ((@C_PRODUTO_IDIMPORECUP <> 'S') AND (@C_PRODUTO_CDCCTBLATIV IS NOT NULL))) BEGIN
              SET @V_IMPOCONTAB = @V_IMPOSINFO;
           END;
         END
         ELSE BEGIN
            IF (@C_PRODUTO_IDTRATIMPO = 'D') BEGIN
              IF NOT(((@C_PRODUTO_IDIMPORECUP = 'S') AND (@C_PRODUTO_CDFISCALIT = '1')) OR
                     ((@C_PRODUTO_IDIMPORECUP <> 'S') AND (@C_PRODUTO_CDCCTBLATIV IS NOT NULL))) BEGIN
                 SET @V_IMPOCONTAB = - @V_IMPOSINFO;
              END;
            END
            ELSE BEGIN
               IF (@C_PRODUTO_IDTRATIMPO = 'R') BEGIN
                 IF (@C_PRODUTO_IDIMPORECUP = 'S') BEGIN
                    IF (@C_PRODUTO_CDCCTBLATIV IS NULL) OR
                       (@C_PRODUTO_CDFISCALIT <> '1') BEGIN
                       SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                    END;
                 END
                 ELSE BEGIN
                    IF (@C_PRODUTO_CDCCTBLATIV IS NULL) BEGIN
                       SET @V_IMPOCONTAB = - @V_IMPOSINFO;
                    END;
                 END;
               END
               ELSE BEGIN
                  SET @V_IMPOCONTAB = 0;
               END;
            END;
         END;
      END;

      IF @C_PRODUTO_IDTRATIMPO = 'A' BEGIN
         UPDATE ITEMPRODUTO
         SET VRCONTITEM = VRCONTITEM + @V_IMPOCONTAB
         WHERE CDFILIAL    = @P_FILIAL   AND
               NRLANCTONF  = @P_LANCTONF AND
               NRSEQITPROD = @C_PRODUTO_NRSEQITPROD;

      END
      ELSE BEGIN
         IF @C_PRODUTO_IDTRATIMPO = 'D' BEGIN
            UPDATE ITEMPRODUTO
            SET VRCONTITEM = VRCONTITEM + @V_IMPOCONTAB
            WHERE CDFILIAL    = @P_FILIAL   AND
                  NRLANCTONF  = @P_LANCTONF AND
                  NRSEQITPROD = @C_PRODUTO_NRSEQITPROD;

         END
         ELSE BEGIN
            UPDATE ITEMPRODUTO
            SET VRCONTITEM = VRCONTITEM + @V_IMPOCONTAB
            WHERE CDFILIAL    = @P_FILIAL   AND
                  NRLANCTONF  = @P_LANCTONF AND
                  NRSEQITPROD = @C_PRODUTO_NRSEQITPROD;

         END;
      END;

      FETCH NEXT FROM C_PRODUTO INTO @C_PRODUTO_NRSEQITPROD, @C_PRODUTO_CDIMPOSTO, @C_PRODUTO_VRPERREDBCIT,
                                     @C_PRODUTO_VRALIQITEM,  @C_PRODUTO_VRPARDEDIT, @C_PRODUTO_CDFISCALIT,
                                     @C_PRODUTO_VRIMPOSTOIT, @C_PRODUTO_IDTRATIMPO, @C_PRODUTO_IDIMPORECUP,
                                     @C_PRODUTO_CDCCTBLPASS, @C_PRODUTO_CDCCTBLATIV, @C_PRODUTO_NRITPROIMPOS,
                                     @C_PRODUTO_IDVALORINFO, @C_PRODUTO_IDTRIMPSTII;
   END;

   CLOSE C_PRODUTO;
   DEALLOCATE C_PRODUTO;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'RECALCULO_ITEM','5.30.000';
GO

